.. _containers:

==================================
Containers (`~ctapipe.containers`)
==================================

.. currentmodule:: ctapipe.containers

Introduction
============

The `ctapipe.containers` module contains the data model definition of all
ctapipe `~ctapipe.core.Container` classes, which provide the container definitions for all
ctapipe data.

The base Container for an event is in `ctapipe.containers.ArrayEventContainer`.


Reference/API
=============

.. automodapi:: ctapipe.containers

